mizu.mizu API documentation
Description: Mizu's core

# Module `mizu.mizu`

Mizu's core

## Functions

`def parse(...)`

  This function is parse markdown to html.

  ## Args

  `text` :`str`
    Markdown content.

  ## Returns

  `str`
    Html content.
`def parse_ext(...)`

  This function is parse markdown to html.

  ## Args

  `text` :`str`
    Markdown content.
  `tables` :`Optional[bool]`
    Enable tables.
  `footnotes` :`Optional[bool]`
    Enable footnotes.
  `strikethrough` :`Optional[bool]`
    Enable strikethrough.
  `tasklists` :`Optional[bool]`
    Enable tasklists.
  `smart_punctuation` :`Optional[bool]`
    Enable smart_punctuation.
  `heading_attribute` :`Optional[bool]`
    Enable heading_attribute.

  ## Returns

  `str`
    Html content.